changeset 10817:3592a3d6bc24

(display_locked): Declare this var.
author Karl Heuer <kwzh@gnu.org>
date Fri, 24 Feb 1995 02:26:46 +0000
parents d172fd0e356f
children 8c81853b2679
files src/lisp.h
diffstat 1 files changed, 7 insertions(+), 1 deletions(-) [+]
line wrap: on
line diff
--- a/src/lisp.h	Fri Feb 24 00:46:15 1995 +0000
+++ b/src/lisp.h	Fri Feb 24 02:26:46 1995 +0000
@@ -536,16 +536,22 @@
 /* The perdisplay object associated with a particular frame.  */
 extern PERDISPLAY *get_perdisplay ();
 
-/* The perdisplay object associated with the currently executing command.  */
+/* The perdisplay object associated with the command currently being read
+   or executed.  */
 extern PERDISPLAY *current_perdisplay;
 
 /* A list of all perdisplay objects, linked through next_perdisplay.  */
 extern PERDISPLAY *all_perdisplays;
+
+/* Nonzero if current_perdisplay has exclusive use of the keyboard.
+   Usually this means that a command is being executed.  */
+extern int display_locked;
 #else
 extern PERDISPLAY the_only_perdisplay;
 #define get_perdisplay(f) (&the_only_perdisplay)
 #define current_perdisplay (&the_only_perdisplay)
 #define all_perdisplays (&the_only_perdisplay)
+#define display_locked 1
 #endif
 
 /* In a cons, the markbit of the car is the gc mark bit */